@@ -39,7 +39,7 @@ class ToolsAppplication(Application):
         if not prefix.can_change(request.user):
             return self.response_forbidden(_("Permission denined"))
         return self.render(request,"index.html",vrf=vrf,afi=afi,prefix=prefix,
-            upload_ips_axfr_form=self.AXFRForm())
+            upload_ips_axfr_form=self.AXFRForm(), rebase_form=self.RebaseForm(prefix.prefix))
     
     ##
     ## Download block's allocated IPs in CSV format
@@ -133,3 +133,47 @@ class ToolsAppplication(Application):
             form=self.AXFRForm()
         return self.render(request,"index.html",vrf=vrf,afi=afi,prefix=prefix,
             upload_ips_axfr_form=form)
+    ##
+    ## Rebase prefix
+    ##
+    class RebaseForm(NOCForm):
+        vrf=forms.ModelChoiceField(label="VRF", queryset=VRF.objects.filter())
+        to_prefix=forms.CharField(label="Rebase to prefix")
+        
+        def __init__(self, prefix, data=None):
+            super(ToolsAppplication.RebaseForm, self).__init__(data)
+            self.prefix=prefix
+        
+        def clean_to_prefix(self):
+            to_prefix=self.cleaned_data["to_prefix"]
+            check_prefix(to_prefix)
+            p0=IP.prefix(self.prefix)
+            p1=IP.prefix(to_prefix)
+            if p0==p1:
+                raise forms.ValidationError("Cannot rebase prefix to self")
+            if p0.afi!=p1.afi:
+                raise forms.ValidationError("Cannot change address family during rebase")
+            if p0.mask<p1.mask:
+                raise forms.ValidationError("Cannot rebase to prefix of lesser size")
+            return to_prefix
+        
+    
+    @view(url=r"^(?P<vrf_id>\d+)/(?P<afi>[46])/(?P<prefix>\S+)/rebase/$",
+        url_name="rebase",
+        access=HasPerm("view"))
+    def view_rebase(self, request, vrf_id, afi, prefix):
+        vrf=self.get_object_or_404(VRF,id=int(vrf_id))
+        prefix=self.get_object_or_404(Prefix, vrf=vrf, afi=afi, prefix=prefix)
+        if request.POST:
+            form=self.RebaseForm(prefix.prefix, request.POST)
+            if form.is_valid():
+                # Rebase prefix
+                new_prefix=prefix.rebase(form.cleaned_data["vrf"], form.cleaned_data["to_prefix"])
+                self.message_user(request, _(u"Prefix %s is rebased to %s"%(prefix, form.cleaned_data["to_prefix"])))
+                return self.response_redirect("ip:ipam:vrf_index",new_prefix.vrf.id,afi,new_prefix.prefix)
+        else:
+            form=self.RebaseForm(prefix.prefix)
+        return self.render(request, "index.html", vrf=vrf, afi=afi, prefix=prefix, rebase_form=form)
+    
+
+    
\ No newline at end of file
