@@ -239,6 +239,42 @@ class Prefix(models.Model):
         # Finally delete
         super(Prefix,self).delete(*args,**kwargs)
     
+    ##
+    ## Delete prefix and all descendancies
+    ##
+    def delete_recursive(self):
+        c=connection.cursor()
+        # Delete nested addresses
+        c.execute("""
+            DELETE FROM %s
+            WHERE
+                    prefix_id IN
+                        (
+                        SELECT id
+                        FROM %s
+                        WHERE
+                                vrf_id=%%s
+                            AND afi=%%s
+                            AND prefix <<= %%s
+                        )"""%(Address._meta.db_table, Prefix._meta.db_table),
+                        [self.vrf.id, self.afi, self.prefix])
+        # Delete nested prefixes
+        c.execute("""
+            DELETE FROM %s
+            WHERE
+                    vrf_id=%%s
+                AND afi=%%s
+                AND prefix <<= %%s
+        """%Prefix._meta.db_table,[self.vrf.id, self.afi, self.prefix])
+        # Delete permissions
+        c.execute("""
+            DELETE FROM %s
+            WHERE
+                    vrf_id=%%s
+                AND afi=%%s
+                AND prefix=%%s
+        """%PrefixAccess._meta.db_table, [self.vrf.id, self.afi, self.prefix])
+    
     ##
     ## List of persons having write access
     ##
@@ -392,6 +428,61 @@ class Prefix(models.Model):
             ORDER BY from_address, to_address
             """, [self.vrf.id, self.afi, self.prefix, self.prefix, self.prefix]))
     
+    ##
+    ## Rebase prefix to a new location
+    ##
+    def rebase(self, vrf, new_prefix):
+        c=connection.cursor()
+        b=IP.prefix(self.prefix)
+        nb=IP.prefix(new_prefix)
+        # Rebase nested prefixes
+        r=[] # (prefix, new_prefix)
+        for p in Prefix.objects.raw("""
+            SELECT *
+            FROM   ip_prefix
+            WHERE
+                    vrf_id=%s
+                AND prefix<<=%s
+        """, [self.vrf.id, self.prefix]):
+            pp=IP.prefix(p.prefix)
+            r+=[(p.prefix, pp.rebase(b, nb).prefix)]
+        for op, np in r:
+            c.execute("UPDATE ip_prefix SET prefix=%s, vrf_id=%s WHERE prefix=%s AND vrf_id=%s", [np, vrf.id, op, self.vrf.id])
+        # Rebase addresses
+        r=[]
+        for a in Address.objects.raw("""
+            SELECT  *
+            FROM    ip_address
+            WHERE
+                    vrf_id=%s
+                AND address<<=%s
+        """,[self.vrf.id, self.prefix]):
+            r+=[(a.address, IP.prefix(a.address).rebase(b, nb).address)]
+        for oa, na in r:
+            c.execute("UPDATE ip_address SET address=%s, vrf_id=%s WHERE address=%s AND vrf_id=%s", [na, vrf.id, oa, self.vrf.id])
+        # Rebase permissions
+        # move all permissions to the nested blocks
+        r=set([a.prefix for a in PrefixAccess.objects.raw("""
+            SELECT  *
+            FROM    ip_prefixaccess
+            WHERE
+                    vrf_id=%s
+                AND prefix<<=%s
+            """,[self.vrf.id, self.prefix])])
+        for p in r:
+            np=IP.prefix(p).rebase(b, nb).prefix
+            c.execute("UPDATE ip_prefixaccess SET prefix=%s, vrf_id=%s WHERE prefix=%s AND vrf_id=%s",[np, vrf.id, p, self.vrf.id])
+        # create permissions for covered blocks
+        for a in PrefixAccess.objects.raw("""
+            SELECT  *
+            FROM    ip_prefixaccess
+            WHERE
+                    vrf_id=%s
+                AND prefix >> %s
+            """, [self.vrf.id, self.prefix]):
+            PrefixAccess(user=a.user, vrf=vrf, afi=a.afi, prefix=new_prefix, can_view=a.can_view, can_change=a.can_change).save()
+        # Return rebased prefix
+        return Prefix.objects.get(vrf=vrf, prefix=new_prefix)
 
 ##
 ## Allocate address
