@@ -345,7 +345,12 @@ class TCPSocket(Socket):
             super(TCPSocket,self).close()
         
     def handle_write(self):
-        sent=self.socket.send(self.out_buffer)
+        try:
+            sent=self.socket.send(self.out_buffer)
+        except socket.error, why:
+            self.error("Socket error: %s"%repr(why))
+            self.close()
+            return
         self.out_buffer=self.out_buffer[sent:]
         if self.in_shutdown and len(self.out_buffer)==0:
             self.close()
@@ -450,7 +455,7 @@ class ConnectedTCPSocket(TCPSocket):
         if self.local_address:
             self.socket.bind((self.local_address,0))
         e=self.socket.connect_ex((self.address,self.port))
-        if e in (ETIMEDOUT, ECONNREFUSED):
+        if e in (ETIMEDOUT, ECONNREFUSED, ENETUNREACH):
             self.on_conn_refused()
             self.close()
             return
