@@ -14,7 +14,8 @@ from django.contrib import admin
 from django.shortcuts import get_object_or_404
 from django import forms
 from django.db.models import Q
-from django.contrib.auth.models import User,Group
+from django.contrib.auth.models import User, Group
+from django.utils.safestring import SafeString
 ## NOC modules
 from noc.lib.app import ModelApplication, site, Permit, PermitSuperuser, HasPerm, PermissionDenied, view
 from noc.sa.models import *
@@ -68,12 +69,36 @@ action_links.allow_tags=True
 def object_status(o):
     s=[]
     if o.is_managed:
-        s+=["Managed"]
+        try:
+            o.profile
+            s+=["<a href='%d/scripts/'><img src='/static/img/managed.png' title='Is Managed' /></a>"%o.id]
+        except:
+            s+=["<img src='/static/img/managed.png' title='Is Managed' />"]
     if o.is_configuration_managed:
-        s+=["Configuration"]
-    return "<br/>".join(s)
-object_status.short_description="Status"
+        try:
+            s+=["<a href='/cm/config/%d/'><img src='/static/img/configuration.png' title='Configuration Managed' /></a>"%o.config.id]
+        except:
+            s+=["<img src='/static/img/configuration.png' title='Configuration Managed' />"]
+
+    return " ".join(s)
+object_status.short_description=u"Status"
 object_status.allow_tags=True
+
+##
+## Administrative domain/activator
+##
+def domain_activator(o):
+    return u"%s/<br/>%s"%(o.administrative_domain.name, o.activator.name)
+domain_activator.short_description=SafeString("Adm. Domain/<br/>Activator")
+domain_activator.allow_tags=True
+##
+## Generic returning safe headers
+##
+def safe_header(name, header):
+    f=lambda o: getattr(o, name)
+    f.short_description=SafeString(header)
+    return f
+
 ##
 ## Reduce task for script results
 ##
@@ -127,7 +152,9 @@ class ManagedObjectAdmin(admin.ModelAdmin):
             "fields": ("tags",)
         }),
     )
-    list_display=["name",object_status,"profile_name","address","administrative_domain","activator","description","repo_path",action_links]
+    list_display=["name", object_status, "profile_name", "address",
+                domain_activator,
+                "description", "repo_path", action_links]
     list_filter=["is_managed","is_configuration_managed","activator","administrative_domain","profile_name"]
     search_fields=["name","address","repo_path","description"]
     object_class=ManagedObject
@@ -198,7 +225,7 @@ class ManagedObjectApplication(ModelApplication):
     def view_script(self,request,object_id,script):
         # Run map/reduce task
         def run_task(**kwargs):
-            task=ReduceTask.create_task([o],script_reduce,{},script,kwargs,60)
+            task=ReduceTask.create_task([o],script_reduce,{},script,kwargs,None)
             return self.response_redirect("sa:managedobject:scriptresult",object_id,script,task.id)
         #
         o=get_object_or_404(ManagedObject,id=int(object_id))
