@@ -13,8 +13,9 @@ from noc.vc.models import VCDomain
 ##
 ##
 ##
-def reduce_topology(task,mac=True,per_vlan_mac=False,arp=True,lldp=False,cdp=False,stp=False,save_data=False):
+def reduce_topology(task,mac=True,per_vlan_mac=False,arp=True,lldp=False,cdp=False,stp=False,save_data=False,mac_port_bindings=False):
     from noc.sa.apps.topologydiscovery.topology import TopologyDiscovery
+    import csv
     data=[(mt.managed_object,mt.script_result) for mt in task.maptask_set.filter(status="C")]
     # Save raw data when required
     out=["Running topology discovery"]
@@ -23,10 +24,16 @@ def reduce_topology(task,mac=True,per_vlan_mac=False,arp=True,lldp=False,cdp=Fal
         with open("/tmp/topo.data","w") as f:
             import cPickle
             cPickle.dump(data,f)
-    td=TopologyDiscovery(data=data,mac=mac,per_vlan_mac=per_vlan_mac,arp=arp,lldp=lldp,cdp=cdp,stp=stp)
+    td=TopologyDiscovery(data=data,mac=mac,per_vlan_mac=per_vlan_mac,arp=arp,lldp=lldp,cdp=cdp,stp=stp,mac_port_bindings=mac_port_bindings)
     out+=["Writting topology into /tmp/topo.dot"]
     with open("/tmp/topo.dot","w") as f:
         f.write(unicode(td.dot()).encode("utf-8"))
+    if mac_port_bindings:
+        out+=["Writing MAC-port bindings into /tmp/mac-port.csv"]
+        with open("/tmp/mac-port.csv", "w") as f:
+            writer=csv.writer(f)
+            for o, i, mac, ip in td.mac_port_bindings:
+                writer.writerow([unicode(o).encode("utf-8"), i, mac, ip])
     return "<br/>".join(out)
 
 ##
@@ -46,6 +53,7 @@ class TopologyDiscoveryAppplication(SAApplication):
         cdp         = forms.BooleanField(label="CDP Neighbor Discovery", initial=False, required=False)
         stp         = forms.BooleanField(label="STP Discovery",          initial=True, required=False)
         save_data   = forms.BooleanField(label="Save Topology Data",     initial=False,required=False)
+        mac_port_bindings = forms.BooleanField(label="MAC-Port bindings",initial=False,required=False)
     
     form=TopologyDiscoveryForm
     ##
